//
//  ViewController.swift
//  iOSNetworkJSON
//
//  Created by xlu on 5/27/22.
//

import UIKit


struct ProductStore: Codable {
    let products: [Product]
    let total, skip, limit: Int
}
struct Product: Codable {
    let id: Int
    let title, descriptionProduct: String
    let price: Int
    let discountPercentage, rating: Double
    let stock: Int
    let brand, category: String
    let thumbnail: String
    let images: [String]
    
        enum CodingKeys: String, CodingKey {
            case id, title
            case descriptionProduct = "description"
            case price, discountPercentage, rating, stock, brand, category, thumbnail, images
        }
}

class ViewController: UIViewController{
    
    @IBOutlet weak var tableView: UITableView!
    
    var allProducts = [Product]()

    override func viewDidLoad() {
        super.viewDidLoad()
        getAllProducts()
        
    }
    
    private func getAllProducts(){
        guard let url = URL(string: "https://dummyjson.com/products") else{
            fatalError("URL Failed")
        }
        
        URLSession.shared.dataTask(with: url){ (data, response, error) in
            if let data = data {
                guard let productall = try? JSONDecoder().decode(ProductStore.self, from: data)else{
                    fatalError("decode error")
                }
                for element in productall.products {
                    self.allProducts.append(element)
                }
            }
            
            DispatchQueue.main.async { [self] in
                tableView.reloadData()
            }
        }.resume()
    }
}

extension ViewController : UITableViewDataSource{
    
    func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        let cell = tableView.dequeueReusableCell(withIdentifier: "ProductTableViewCell", for: indexPath) as! ProductTableViewCell
        
        let productObj = allProducts[indexPath.row]
        
        cell.ProductDescription.text = productObj.descriptionProduct
        
        return cell
    }
    
    func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return allProducts.count
    }
    
    func numberOfSections(in tableView: UITableView) -> Int {
        return 1
    }
    
}


